@@ -27,7 +27,7 @@
 import os
 
 import pyworkflow.protocol.params as params
-from pyworkflow.constants import BETA
+from pyworkflow.constants import PROD
 from pwem.protocols import ProtAnalysis3D
 from pwem.objects import Volume
 from pwem.emlib.image import ImageHandler
@@ -43,7 +43,11 @@ class ProtSideSplitter(ProtAnalysis3D):
     Find more information at https://github.com/StructuralBiology-ICLMedicine/SIDESPLITTER
     """
     _label = 'local filter'
-    _devStatus = BETA
+    _devStatus = PROD
+    _possibleOutputs = {
+        'outputVolume1': Volume,
+        'outputVolume2': Volume
+    }
 
     def _createFilenameTemplates(self):
         """ Centralize how files are called. """
